/**************************************************************************//**
*   @file   gpio.h
*   @brief  Contains the implementations of GPIO acces macros.
*   @author acozma (andrei.cozma@analog.com)
*
*******************************************************************************
* Copyright 2011(c) Analog Devices, Inc.
*
* All rights reserved.
*
* Redistribution and use in source and binary forms, with or without modification,
* are permitted provided that the following conditions are met:
*  - Redistributions of source code must retain the above copyright
*    notice, this list of conditions and the following disclaimer.
*  - Redistributions in binary form must reproduce the above copyright
*    notice, this list of conditions and the following disclaimer in
*    the documentation and/or other materials provided with the
*    distribution.
*  - Neither the name of Analog Devices, Inc. nor the names of its
*    contributors may be used to endorse or promote products derived
*    from this software without specific prior written permission.
*  - The use of this software may or may not infringe the patent rights
*    of one or more patent holders.  This license does not release you
*    from the requirement that you obtain separate licenses from these
*    patent holders to use this software.
*  - Use of the software either in source or binary form, must be run
*    on or directly connected to an Analog Devices Inc. component.
*
* THIS SOFTWARE IS PROVIDED BY ANALOG DEVICES "AS IS" AND ANY EXPRESS OR IMPLIED
* WARRANTIES, INCLUDING, BUT NOT LIMITED TO, NON-INFRINGEMENT, MERCHANTABILITY
* AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
* IN NO EVENT SHALL ANALOG DEVICES BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
* SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
* INTELLECTUAL PROPERTY RIGHTS, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
* LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
* ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
* (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
* SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*
*******************************************************************************
*   SVN Revision: 468
******************************************************************************/
#ifndef __GPIO_H__
#define __GPIO_H__

/*****************************************************************************/
/***************************** Include Files *********************************/
/*****************************************************************************/
#include "xil_io.h"

/*****************************************************************************/
/******************* GPIO Registers Definitions ******************************/
/*****************************************************************************/
#define GPIO_DATA	0x00
#define GPIO_TRI    0x04
#define GPIO2_DATA  0x08
#define GPIO2_TRI	0x0C

/*****************************************************************************/
/******************* Macros and Constants Definitions ************************/
/*****************************************************************************/
#define GPIO_SET_OUTPUT_PINS(GPIO_BASE_ADDR, cfgWord) \
	Xil_Out32((GPIO_BASE_ADDR + GPIO_TRI), cfgWord);

#define GPIO_GET_DATA(GPIO_BASE_ADDR) \
	Xil_In32((GPIO_BASE_ADDR + GPIO_DATA))

#define GPIO_SET_DATA(GPIO_BASE_ADDR, cfgWord) \
	Xil_Out32((GPIO_BASE_ADDR + GPIO_DATA), cfgWord);

#define GPIO_SET_BITS(GPIO_BASE_ADDR, cfgWord) \
{ \
	int currCfgWord = 0; \
	currCfgWord = Xil_In32((GPIO_BASE_ADDR + GPIO_DATA)); \
	Xil_Out32((GPIO_BASE_ADDR + GPIO_DATA), currCfgWord | cfgWord); \
}

#define GPIO_CLEAR_BITS(GPIO_BASE_ADDR, cfgWord) \
{ \
	int currCfgWord = 0; \
	currCfgWord = Xil_In32((GPIO_BASE_ADDR + GPIO_DATA)); \
	Xil_Out32((GPIO_BASE_ADDR + GPIO_DATA), currCfgWord & ~cfgWord); \
}

#define GPIO2_SET_OUTPUT_PINS(GPIO_BASE_ADDR, cfgWord) \
	Xil_Out32((GPIO_BASE_ADDR + GPIO2_TRI), cfgWord);

#define GPIO2_GET_DATA(GPIO_BASE_ADDR) \
	Xil_In32((GPIO_BASE_ADDR + GPIO2_DATA))

#define GPIO2_SET_DATA(GPIO_BASE_ADDR, cfgWord) \
	Xil_Out32((GPIO_BASE_ADDR + GPIO2_DATA), cfgWord);

#define GPIO2_SET_BITS(GPIO_BASE_ADDR, cfgWord) \
{ \
	int currCfgWord = 0; \
	currCfgWord = Xil_In32((GPIO_BASE_ADDR + GPIO2_DATA)); \
	Xil_Out32((GPIO_BASE_ADDR + GPIO2_DATA), currCfgWord | cfgWord); \
}

#define GPIO2_CLEAR_BITS(GPIO_BASE_ADDR, cfgWord) \
{ \
	int currCfgWord = 0; \
	currCfgWord = Xil_In32((GPIO_BASE_ADDR + GPIO2_DATA)); \
	Xil_Out32((GPIO_BASE_ADDR + GPIO2_DATA), currCfgWord & ~cfgWord); \
}

#endif /* __GPIO_H__ */
